==> mac-10.87.zip: Source/Shared/GlobalFunctions.h <==
#pragma once

namespace APE
{

/**************************************************************************************************
Definitions
**************************************************************************************************/
class CIO;

/**************************************************************************************************
Read / Write from an IO source and return failure if the number of bytes specified
isn't read or written
**************************************************************************************************/
int ReadSafe(CIO * pIO, void * pBuffer, int nBytes);
intn WriteSafe(CIO * pIO, void * pBuffer, intn nBytes);

/**************************************************************************************************
Checks for the existence of a file
**************************************************************************************************/
bool FileExists(const wchar_t * pFilename);

/**************************************************************************************************
Allocate aligned memory
**************************************************************************************************/
void * AllocateAligned(intn nBytes, intn nAlignment);
void FreeAligned(void * pMemory);

/**************************************************************************************************
String helpers
**************************************************************************************************/
bool StringIsEqual(const str_utfn * pString1, const str_utfn * pString2, bool bCaseSensitive, int nCharacters = -1);

}

==> mac-11.08.zip: Source/Shared/GlobalFunctions.h <==
#pragma once

namespace APE
{

/**************************************************************************************************
Definitions
**************************************************************************************************/
class CIO;

/**************************************************************************************************
Read / Write from an IO source and return failure if the number of bytes specified
isn't read or written
**************************************************************************************************/
int ReadSafe(CIO * pIO, void * pBuffer, int nBytes);
intn WriteSafe(CIO * pIO, void * pBuffer, intn nBytes);

/**************************************************************************************************
Checks for the existence of a file
**************************************************************************************************/
bool FileExists(const wchar_t * pFilename);

/**************************************************************************************************
Allocate aligned memory
**************************************************************************************************/
void * AllocateAligned(intn nBytes, intn nAlignment);
void FreeAligned(void * pMemory);

/**************************************************************************************************
String helpers
**************************************************************************************************/
bool StringIsEqual(const str_utfn * pString1, const str_utfn * pString2, bool bCaseSensitive, int nCharacters = -1);

/**************************************************************************************************
Byte order conversion
**************************************************************************************************/
uint32 SwitchByteOrder(uint32 nValue);
void SwitchBufferByteOrder(uint32 * pBuffer, uint32 nWords);

}
